==> org.eclipse.sapphire.ui.source_0.1.0.201101041550.jar: org/eclipse/sapphire/ui/SapphirePropertyEnabledCondition.java <==
/******************************************************************************
 * Copyright (c) 2011 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.sapphire.ui;

import java.util.Collections;
import java.util.List;

import org.eclipse.sapphire.modeling.IModelElement;
import org.eclipse.sapphire.modeling.ModelProperty;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public class SapphirePropertyEnabledCondition

    extends SapphireCondition
    
{
    private ModelProperty property;
    
    @Override
    public void init( final SapphirePartContext context,
                      final String parameter )
    {
        super.init( context, parameter );
        
        final IModelElement element = this.context.getModelElement();
        this.property = element.getModelElementType().getProperty( parameter );
    }

    @Override
    public boolean evaluate()
    {
        if( this.property != null )
        {
            final IModelElement element = this.context.getModelElement();
            return element.isPropertyEnabled( this.property );
        }

        return false;
    }

    @Override
    public List<String> getDependencies()
    {
        return Collections.singletonList( this.property.getName() );
    }
    
}

==> org.eclipse.sapphire.ui.source_0.3.0.201106221325.jar: org/eclipse/sapphire/ui/SapphirePropertyEnabledCondition.java <==
/******************************************************************************
 * Copyright (c) 2011 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.sapphire.ui;

import java.util.Collections;
import java.util.List;

import org.eclipse.sapphire.modeling.IModelElement;
import org.eclipse.sapphire.modeling.ModelProperty;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public class SapphirePropertyEnabledCondition

    extends SapphireModelCondition
    
{
    private ModelProperty property;
    
    @Override
    public void initCondition( final ISapphirePart part,
                               final String parameter )
    {
        final IModelElement element = part.getModelElement();
        this.property = element.getModelElementType().getProperty( parameter );

        super.initCondition( part, parameter );
    }

    @Override
    public boolean evaluate()
    {
        if( this.property != null )
        {
            final IModelElement element = getPart().getModelElement();
            return element.isPropertyEnabled( this.property );
        }

        return false;
    }

    @Override
    public List<String> getDependencies()
    {
        return Collections.singletonList( this.property.getName() );
    }
    
}
